<?php

namespace Smac\APIBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Smac\APIBundle\Entity\TwitterToken;
use Smac\ProjectBundle\Entity\Project;
use Smac\MessageBundle\Document\Message;
use Smac\APIBundle\Entity\TwitterRequest;

class TwitterController extends Controller
{
    /**
     * Conecta por primera vez con Twitter y pide los token
     *
     * @return RedirectResponse
     */
    public function connectAction()
    {
        $em = $this->getDoctrine()->getManager();
        $twitter = $this->get('fos_twitter.service');
        $request = $this->getRequest();
        $session = $request->getSession();

        //petición de la URL para conexión del servicio
        $authURL = $twitter->getLoginUrl($request);
        $response = new RedirectResponse($authURL);

        //almaceno información de la petición en la base de datos
        $proj = $session->get('smac_context');
        $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);
        $twitterRequest = new TwitterRequest();
        $twitterRequest->setDate(new \DateTime());
        $twitterRequest->setType(TwitterRequest::TWITTER_REQUEST_TYPE_CONNECT);
        $twitterRequest->setProject($project);
        $em->persist($twitterRequest);
        $em->flush();

        return $response;
    }

    /**
     * Twitter devuelve el Token del usuario aceptado y lo guardamos en base de datos
     *
     * @return RedirectResponse
     * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
     */
    public function connectCallbackAction()
    {
        $request = $this->getRequest();
        $token = $request->query->get('oauth_token');
        $verifier = $request->query->get('oauth_verifier');
        $session = $request->getSession();
        $em = $this->getDoctrine()->getManager();

        $proj = $session->get('smac_context');

        //verificamos el token recibido con el servicio
        $twitter = $this->get('fos_twitter.service');
        $accessToken = $twitter->getAccessToken($token, $verifier);

        //creo la entidad Token para guardarlo
        $twitterToken = new TwitterToken();
        $twitterToken->setOauthToken($accessToken['oauth_token']);
        $twitterToken->setOauthTokenSecret($accessToken['oauth_token_secret']);
        $twitterToken->setUserId($accessToken['user_id']);
        $twitterToken->setScreenName($accessToken['screen_name']);

        //lo asocio al proyecto
        $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);

        if (!$project) {
            throw $this->createNotFoundException('El proyecto no existe');
        }

        //lo asocio al proyecto
        $project->setTwitterToken($twitterToken);

        //lo guardamos en la base de datos
        $em->persist($twitterToken);
        $em->persist($project);
        $em->flush();

        $this->get('session')->getFlashBag()->add(
            'success',
            'Conexión con Twitter correcta'
        );

        return $this->redirect($this->generateUrl('smac_project_edit'));
    }


    /**
     * Sinctoniza con mensajes de Twitter, segun las ultimas peticiones.
     * Si $type es "old", sincronizará hacia atras
     * Si $Type es "new", sincronizará mensajes nuevos
     *
     * @param $type
     * @return Response
     */
    public function syncAction($type)
    {
        $request = $this->getRequest();
        $session = $request->getSession();
        $twitter = $this->get('fos_twitter.api');
        $twitter->host = "https://api.twitter.com/1.1/";
        $params = array();
        $em = $this->getDoctrine()->getManager();
        $dm = $this->get('doctrine_mongodb')->getManager();

        $proj = $session->get('smac_context');
        $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);
        $token = $project->getTwitterToken();

        //miro la ultima sync
        $result = $em->getRepository('SmacAPIBundle:TwitterRequest')->findLastRequest($project, $token, TwitterRequest::TWITTER_REQUEST_TYPE_MENTIONS);

        $first = $result['first'];
        $last = $result['last'];

        if ($type == 'old') {
            $param_name = 'max_id';
            $param_value = $last;
        } elseif ($type == 'new') {
            $param_name = 'since_id';
            $param_value = $first;
        }

        if ($result) {
            $params[$param_name] = (string)$param_value;
        }

        //conecto con la API de twitter para pedir menciones de timeline
        $twitter->setOAuthToken($token->getOauthToken(), $token->getOauthTokenSecret());
        $response = $twitter->get(
            'statuses/mentions_timeline',
            $params
        );

        //guardo mensajes en mongo
        $lastId = 0;
        $firstId = 0;
        $count = 0;

        if (count($response)>0) {
            foreach ($response as $tweet) {
                if ($count==0) {
                    $firstId = $tweet->id_str;
                }
                $message = new Message();
                $message->setProject($proj);
                $message->setUsername($tweet->user->name);
                $message->setUser($tweet->user->screen_name);
                $message->setDateCreated(new \DateTime($tweet->created_at));
                $message->setDateReg(new \DateTime());
                $message->setRaw(json_encode($tweet));
                $message->setSource(Message::MESSAGE_SOURCE_TWITTER);
                $message->setText($tweet->text);
                $message->setVisibility(Message::MESSAGE_VISIBILITY_PUBLIC);
                $count++;
                $dm->persist($message);

                $lastId = $tweet->id_str;
            }

            $dm->flush();

            //logueo el request y last ID para futuras sync
            $twitterRequest = new TwitterRequest();
            $twitterRequest->setDate(new \DateTime());
            $twitterRequest->setType(TwitterRequest::TWITTER_REQUEST_TYPE_MENTIONS);
            $twitterRequest->setProject($project);

            if ($type == 'old') {
                $twitterRequest->setLast(($lastId > 0 ? $lastId : $param_value));
                $twitterRequest->setFirst(($firstId > $first ? $firstId : $first));
            } elseif ($type == 'new') {
                $twitterRequest->setFirst(($firstId > 0 ? $firstId : $param_value));
                $twitterRequest->setLast(($lastId < $last || $last == 0 ? $lastId : $last));
            }

            $twitterRequest->setToken($token);
            $em->persist($twitterRequest);
            $em->flush();


        }

        return new Response(json_encode(array('synced'=>$count)), 200, array('Content-Type'=>'application/json'));
    }

    public function testAction()
    {

    }

    public function backAction()
    {

    }
}