<?php

namespace Smac\APIBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * TwitterRequest
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="Smac\APIBundle\Entity\TwitterRequestRepository")
 */
class TwitterRequest
{
    const TWITTER_REQUEST_TYPE_CONNECT = 1;
    const TWITTER_REQUEST_TYPE_MENTIONS = 2;
    const TWITTER_REQUEST_TYPE_DMS = 3;

    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var integer
     *
     * @ORM\Column(name="type", type="integer")
     * @Assert\NotBlank()
     */
    private $type;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\ProjectBundle\Entity\Project", inversedBy="requests")
     * @ORM\JoinColumn(name="project_id", referencedColumnName="id")
     */
    private $project;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\APIBundle\Entity\TwitterToken", inversedBy="requests")
     * @ORM\JoinColumn(name="token_id", referencedColumnName="id")
     */
    private $token;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_reg", type="datetime")
     */
    private $date;

    /**
     * @var string
     *
     * @ORM\Column(name="first", type="string", length=255)
     */
    private $first = 0;

    /**
     * @var string
     *
     * @ORM\Column(name="last", type="string", length=255)
     */
    private $last = 0;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set type
     *
     * @param integer $type
     * @return TwitterRequest
     */
    public function setType($type)
    {
        $this->type = $type;

        return $this;
    }

    /**
     * Get type
     *
     * @return integer 
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Set date
     *
     * @param \DateTime $date
     * @return TwitterRequest
     */
    public function setDate($date)
    {
        $this->date = $date;

        return $this;
    }

    /**
     * Get date
     *
     * @return \DateTime 
     */
    public function getDate()
    {
        return $this->date;
    }

    /**
     * Set project
     *
     * @param \Smac\ProjectBundle\Entity\Project $project
     * @return TwitterRequest
     */
    public function setProject(\Smac\ProjectBundle\Entity\Project $project = null)
    {
        $this->project = $project;

        return $this;
    }

    /**
     * Get project
     *
     * @return \Smac\ProjectBundle\Entity\Project 
     */
    public function getProject()
    {
        return $this->project;
    }

    /**
     * Set token
     *
     * @param \Smac\APIBundle\Entity\TwitterToken $token
     * @return TwitterRequest
     */
    public function setToken(\Smac\APIBundle\Entity\TwitterToken $token = null)
    {
        $this->token = $token;

        return $this;
    }

    /**
     * Get token
     *
     * @return \Smac\APIBundle\Entity\TwitterToken 
     */
    public function getToken()
    {
        return $this->token;
    }

    /**
     * Set last
     *
     * @param integer $last
     * @return TwitterRequest
     */
    public function setLast($last)
    {
        $this->last = $last;

        return $this;
    }

    /**
     * Get last
     *
     * @return integer 
     */
    public function getLast()
    {
        return $this->last;
    }

    /**
     * Set first
     *
     * @param string $first
     * @return TwitterRequest
     */
    public function setFirst($first)
    {
        $this->first = $first;

        return $this;
    }

    /**
     * Get first
     *
     * @return string 
     */
    public function getFirst()
    {
        return $this->first;
    }
}
