<?php

namespace Smac\MessageBundle\Controller;

use Smac\MessageBundle\Document\Message;
use Smac\TicketBundle\Entity\Ticket;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Smac\MessageBundle\Form\MessageType;
use Symfony\Component\HttpFoundation\Response;

class DefaultController extends Controller
{
    public function homeAction()
    {
        return $this->render('SmacMessageBundle:Default:home.html.twig');
    }

    public function classifyAction()
    {
        $request = $this->getRequest();
        $session = $request->getSession();

        $proj = (int)$session->get('smac_context');

        $em = $this->getDoctrine()->getManager();
        $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);

        return $this->render(
            'SmacMessageBundle:Default:classify.html.twig',
            array(
                'project' => $project
            )
        );
    }

    public function classifyListAction()
    {
        $request = $this->getRequest();
        $session = $request->getSession();

        $proj = (int)$session->get('smac_context');

        $messages = $this->get('doctrine_mongodb')
            ->getManager()
            ->getRepository('SmacMessageBundle:Message')
            ->findPendingForClassify($proj);

        $em = $this->getDoctrine()->getManager();
        $categories = $em->getRepository('SmacProjectBundle:Category')->findFromProject($proj);
        $typologies = $em->getRepository('SmacProjectBundle:Typology')->findFromProject($proj);

        return $this->render(
            'SmacMessageBundle:Default:classify_list.html.twig',
            array(
                'messages' => $messages,
                'categories' => $categories,
                'typologies' => $typologies
            )
        );
    }

    public function createAction()
    {
        $request = $this->getRequest();
        $session = $request->getSession();

        $message = new Message();
        $form = $this->createForm(new MessageType(), $message);

        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if ($form->isValid()) {

                $proj = $session->get('smac_context');

                $message->setDateReg(new \DateTime());
                $message->setProject($proj);

                $dm = $this->get('doctrine_mongodb')->getManager();
                $dm->persist($message);
                $dm->flush();

                return $this->redirect($this->generateUrl('smac_message_create_landing'));
            }
        }

        return $this->render(
            'SmacMessageBundle:Default:create.html.twig',
            array(
                'form' => $form->createView()
            )
        );
    }

    public function createLandingAction()
    {
        //@todo: toggle + info

        return $this->render('SmacMessageBundle:Default:create_landing.html.twig');
    }

    /**
     * Clasifica un mensaje, actualizando todos los datos mediante AJAX
     *
     * @return Response
     * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
     */
    public function updateAction()
    {
        $request = $this->getRequest();
        $form = $request->request;

        //recibo todos los datos por POST
        $mId = $form->get('message-id');
        $cat = $form->get('category');
        $subcat = (int)$form->get('subcategory');
        $typ = $form->get('typology');
        $genTicket = $form->has('ticket');

        //obtengo el mensaje desde MongoDB
        $message = $this->get('doctrine_mongodb')
            ->getRepository('SmacMessageBundle:Message')
            ->find($mId);

        if (!$message) {
            throw $this->createNotFoundException('Mensaje no encontrado');
        }

        //actualizo los datos y guardo
        $dm = $this->get('doctrine_mongodb')->getManager();
        $message->setDateClassified(new \DateTime());
        $message->setCategory($cat);
        $message->setTypology($typ);
        if ($subcat > 0) {
            $message->setSubcategory($subcat);
        }
        $dm->persist($message);
        $dm->flush();

        //si me piden generar ticket genero entidad y la persisto
        if ($genTicket) {
            $request = $this->getRequest();
            $session = $request->getSession();
            $proj = (int)$session->get('smac_context');
            $em = $this->getDoctrine()->getManager();

            $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);
            $user = $this->get('security.context')->getToken()->getUser();

            $ticket = new Ticket();
            $ticket->setUser($user);
            $ticket->setAssigned($user);
            $ticket->setDateReg(new \DateTime());
            $ticket->setMessageUuid($mId);
            $ticket->setProject($project);
            $ticket->setStatus(Ticket::TICKET_STATUS_OPENED);
            $em->persist($ticket);
            $em->flush();
        }

        //devuelvo un "ok" para el ajax
        return new Response(json_encode(array('saved'=>true)), 200, array('Content-Type'=>'application/json'));
    }
}