<?php

namespace Smac\ProjectBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Smac\ProjectBundle\Entity\RelProjectUser;
use Symfony\Component\HttpFoundation\Response;

class UserController extends Controller
{
    public function attachUserAction()
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $session = $request->getSession();

        $proj = $session->get('smac_context');
        $currUser = $this->get('security.context')->getToken()->getUser();
        $attachedUsersRAW = $em->getRepository('SmacProjectBundle:Project')->findAttachedUsers($proj);

        //@todo: pasarlo a un service
        $attachedUsers = array();
        foreach ($attachedUsersRAW as $relUser) {
            $user = $relUser->getUser();
            $data = array();

            $data['rel_id'] = $relUser->getId();
            $data['name'] = $user->getName()." ".$user->getSurname()."(".$user->getEmail().")";

            $roles = explode("|", $relUser->getRoles());
            $data['gestor'] = array('disabled' => ($currUser==$user), 'checked' => in_array(RelProjectUser::ROLE_MANAGER, $roles));
            $data['analista'] = array('disabled' => ($currUser==$user), 'checked' => in_array(RelProjectUser::ROLE_ANALIST, $roles));
            $data['cm'] = array('disabled' => ($currUser==$user), 'checked' => in_array(RelProjectUser::ROLE_CM, $roles));
            $data['cc'] = array('disabled' => ($currUser==$user), 'checked' => in_array(RelProjectUser::ROLE_CC, $roles));

            $attachedUsers[] = $data;
        }

        $elegibleUsers = $em->getRepository('SmacProjectBundle:Project')->findElegibleUsers($proj);

        return $this->render(
            'SmacProjectBundle:User:attach_user.html.twig',
            array(
                'attachedUsers' => $attachedUsers,
                'elegibleUsers' => $elegibleUsers
            )
        );
    }

    public function attachNewUserAction()
    {
        $request = $this->getRequest();

        if ($request->getMethod() == 'POST') {

            $form = $request->request;
            $user_id = $form->get('user');

            $em = $this->getDoctrine()->getManager();
            $session = $request->getSession();

            $proj = $session->get('smac_context');

            $user = $em->getRepository('SmacUserBundle:User')->find($user_id);
            $project = $em->getRepository('SmacProjectBundle:Project')->find($proj);

            $rel = new RelProjectUser();
            $rel->setUser($user);
            $rel->setProject($project);

            //\Doctrine\Common\Util\Debug::dump($rel);

            $em->persist($rel);
            $em->flush();

            $this->get('session')->getFlashBag()->add(
                'success',
                'Usuario adjuntado correctamente'
            );
            return $this->redirect($this->generateUrl('smac_project_user_attach'));
        }
    }

    public function detachUserAction($id)
    {
        $request = $this->getRequest();

        $em = $this->getDoctrine()->getManager();

        $rel = $em->getRepository('SmacProjectBundle:RelProjectUser')->find($id);

        if (!$rel) {
            throw $this->createNotFoundException('No se ha encontrado la relación');
        }

        $em->remove($rel);
        $em->flush();

        $this->get('session')->getFlashBag()->add(
            'success',
            'Usuario eliminado del proyecto'
        );
        return $this->redirect($this->generateUrl('smac_project_user_attach'));
    }

    public function saveUserAction($id)
    {
        $request = $this->getRequest();
        $form = $request->request;
        $em = $this->getDoctrine()->getManager();

        $rel = $em->getRepository('SmacProjectBundle:RelProjectUser')->find($id);

        $roles = array();
        if ($form->has('gestor')) {
            array_push($roles, RelProjectUser::ROLE_MANAGER);
        } elseif ($form->has('analista')) {
            array_push($roles, RelProjectUser::ROLE_ANALIST);
        } elseif ($form->has('cm')) {
            array_push($roles, RelProjectUser::ROLE_CM);
        } elseif ($form->has('cc')) {
            array_push($roles, RelProjectUser::ROLE_CC);
        }

        $rel->setRoles(implode('|', $roles));
        $em->persist($rel);
        $em->flush();

        return new Response(json_encode(array('saved'=>true)), 200, array('Content-Type'=>'application/json'));
    }
}

