<?php

namespace Smac\ProjectBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Category
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="Smac\ProjectBundle\Entity\CategoryRepository")
 */
class Category
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank()
     */
    private $name;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\ProjectBundle\Entity\Project", inversedBy="categories")
     * @ORM\JoinColumn(name="project_id", referencedColumnName="id")
     */
    private $project;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\ProjectBundle\Entity\Category", inversedBy="childrenCategories")
     * @ORM\JoinColumn(name="parent_id", referencedColumnName="id")
     */
    private $parentCategory;

    /**
     * @ORM\OneToMany(targetEntity="Smac\ProjectBundle\Entity\Category", mappedBy="parentCategory")
     */
    private $childrenCategories;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Category
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set project
     *
     * @param \Smac\ProjectBundle\Entity\Project $project
     * @return Category
     */
    public function setProject(\Smac\ProjectBundle\Entity\Project $project = null)
    {
        $this->project = $project;

        return $this;
    }

    /**
     * Get project
     *
     * @return \Smac\ProjectBundle\Entity\Project 
     */
    public function getProject()
    {
        return $this->project;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->childrenCategories = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     * Set parentCategory
     *
     * @param \Smac\ProjectBundle\Entity\Category $parentCategory
     * @return Category
     */
    public function setParentCategory(\Smac\ProjectBundle\Entity\Category $parentCategory = null)
    {
        $this->parentCategory = $parentCategory;

        return $this;
    }

    /**
     * Get parentCategory
     *
     * @return \Smac\ProjectBundle\Entity\Category 
     */
    public function getParentCategory()
    {
        return $this->parentCategory;
    }

    /**
     * Add childrenCategories
     *
     * @param \Smac\ProjectBundle\Entity\Category $childrenCategories
     * @return Category
     */
    public function addChildrenCategory(\Smac\ProjectBundle\Entity\Category $childrenCategories)
    {
        $this->childrenCategories[] = $childrenCategories;

        return $this;
    }

    /**
     * Remove childrenCategories
     *
     * @param \Smac\ProjectBundle\Entity\Category $childrenCategories
     */
    public function removeChildrenCategory(\Smac\ProjectBundle\Entity\Category $childrenCategories)
    {
        $this->childrenCategories->removeElement($childrenCategories);
    }

    /**
     * Get childrenCategories
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getChildrenCategories()
    {
        return $this->childrenCategories;
    }
}
