<?php

namespace Smac\ProjectBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Project
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="Smac\ProjectBundle\Entity\ProjectRepository")
 */
class Project
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank()
     */
    private $name;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_reg", type="datetime")
     */
    private $dateReg;

    /**
     * @ORM\Column(type="text")
     */
    private $description;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\UserBundle\Entity\User", inversedBy="createdProjects")
     * @ORM\JoinColumn(name="user_id", referencedColumnName="id")
     */
    private $user;

    /**
     * @ORM\OneToMany(targetEntity="Smac\ProjectBundle\Entity\RelProjectUser", mappedBy="project")
     */
    private $relUsers;

    /**
     * @ORM\OneToMany(targetEntity="Smac\ProjectBundle\Entity\Category", mappedBy="project")
     */
    private $categories;

    /**
     * @ORM\OneToOne(targetEntity="Smac\APIBundle\Entity\TwitterToken")
     * @ORM\JoinColumn(name="twitter_token_id", referencedColumnName="id")
     **/
    private $twitterToken;

    public function __construct()
    {
        $this->dateReg = new \DateTime();
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Project
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set dateReg
     *
     * @param \DateTime $dateReg
     * @return Project
     */
    public function setDateReg($dateReg)
    {
        $this->dateReg = $dateReg;
    
        return $this;
    }

    /**
     * Get dateReg
     *
     * @return \DateTime 
     */
    public function getDateReg()
    {
        return $this->dateReg;
    }

    /**
     * Set user
     *
     * @param \Smac\UserBundle\Entity\User $user
     * @return Project
     */
    public function setUser(\Smac\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \Smac\UserBundle\Entity\User
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Project
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Add relUsers
     *
     * @param \Smac\ProjectBundle\Entity\RelProjectUser $relUsers
     * @return Project
     */
    public function addRelUser(\Smac\ProjectBundle\Entity\RelProjectUser $relUsers)
    {
        $this->relUsers[] = $relUsers;
    
        return $this;
    }

    /**
     * Remove relUsers
     *
     * @param \Smac\ProjectBundle\Entity\RelProjectUser $relUsers
     */
    public function removeRelUser(\Smac\ProjectBundle\Entity\RelProjectUser $relUsers)
    {
        $this->relUsers->removeElement($relUsers);
    }

    /**
     * Get relUsers
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getRelUsers()
    {
        return $this->relUsers;
    }

    /**
     * Add categories
     *
     * @param \Smac\ProjectBundle\Entity\Category $categories
     * @return Project
     */
    public function addCategory(\Smac\ProjectBundle\Entity\Category $categories)
    {
        $this->categories[] = $categories;

        return $this;
    }

    /**
     * Remove categories
     *
     * @param \Smac\ProjectBundle\Entity\Category $categories
     */
    public function removeCategory(\Smac\ProjectBundle\Entity\Category $categories)
    {
        $this->categories->removeElement($categories);
    }

    /**
     * Get categories
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCategories()
    {
        return $this->categories;
    }

    /**
     * Set twitterToken
     *
     * @param \Smac\APIBundle\Entity\TwitterToken $twitterToken
     * @return Project
     */
    public function setTwitterToken(\Smac\APIBundle\Entity\TwitterToken $twitterToken = null)
    {
        $this->twitterToken = $twitterToken;

        return $this;
    }

    /**
     * Get twitterToken
     *
     * @return \Smac\APIBundle\Entity\TwitterToken 
     */
    public function getTwitterToken()
    {
        return $this->twitterToken;
    }
}
