<?php

namespace Smac\ReportBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Ob\HighchartsBundle\Highcharts\Highchart;

class DefaultController extends Controller
{
    public function homeAction()
    {
        return $this->render('SmacReportBundle:Default:home.html.twig');
    }

    /**
     * Genera un informe comprendido entre dos fechas de todos los mensajes clasificados
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function generateAction()
    {
        $request = $this->getRequest();
        $form = $request->request;
        $session = $request->getSession();

        //recibo las dos fechas
        $ini = $form->get('date-ini');
        $end = $form->get('date-end');

        $dini = \DateTime::createFromFormat('d/m/Y', $ini);
        $dend = \DateTime::createFromFormat('d/m/Y', $end);

        $proj = (int)$session->get('smac_context');

        //todos los mensajes clasificados entre las fechas
        $messages = $this->get('doctrine_mongodb')
            ->getManager()
            ->getRepository('SmacMessageBundle:Message')
            ->findClassifiedBetweenDates($proj, $dini, $dend);

        $classify = null;

        if (count($messages)>0) {
            $em = $this->getDoctrine()->getManager();
            //numero de tickets clasificados por categorias
            //...por subcategorias
            //...por tipologias
            //...por source
            //totales
            $classify = $this->classify($messages);
            $categories = $em->getRepository('SmacProjectBundle:Category')->findFromProject($proj);
            $subcategories = $em->getRepository('SmacProjectBundle:Category')->findSubcategoriesFromProject($proj);
            $typologies = $em->getRepository('SmacProjectBundle:Typology')->findFromProject($proj);

            //por visibilidad
            //@todo

            //tickets generados
            //@todo

            //tickets resueltos
            //@todo

            //mensajes sincronizados
            //@todo

            //API Chart
            $ob = new Highchart();
            $ob->chart->renderTo('linechart');
            $ob->title->text('Mensajes por categorias en el rango');
            $ob->plotOptions->pie(
                array(
                    'allowPointSelect'  => true,
                    'cursor'    => 'pointer',
                    'dataLabels'    => array('enabled' => false),
                    'showInLegend'  => true
                )
            );
            $ob->chart->width(600);
            $data = array();
            foreach ($categories as $category) {
                $data[] = array($category->getName(), $classify['categories'][$category->getId()]);
            }

            $ob->series(array(array('type' => 'pie','name' => 'Mensajes', 'data' => $data)));

            //render final
            return $this->render(
                'SmacReportBundle:Default:report.html.twig',
                array(
                    'ini' => $ini,
                    'end' => $end,
                    'classify' => $classify,
                    'categories' => $categories,
                    'subcategories' => $subcategories,
                    'typologies' => $typologies,
                    'chart' => $ob
                )
            );
        } else {
            return $this->render('SmacReportBundle:Default:report_no_results.html.twig');
        }
    }


    /**
     * Función que itera todos los mensajes y los va clasificando segun tipos
     *
     * @param $messages
     * @return array
     */
    private function classify($messages)
    {
        $ret = array();
        $ret['categories'] = array();
        $ret['subcategories'] = array();
        $ret['typologies'] = array();
        $ret['source'] = array();
        $ret['total'] = count($messages);

        foreach ($messages as $msg) {
            $this->increment($ret['categories'], $msg->getCategory());
            $this->increment($ret['subcategories'], $msg->getSubcategory());
            $this->increment($ret['typologies'], $msg->getTypology());
            $this->increment($ret['source'], $msg->getSource());
        }

        return $ret;
    }

    /**
     * Incrementa el valor de un array o lo crea si no existe
     *
     * @param $arr
     * @param $key
     */
    private function increment(&$arr, $key)
    {
        if (array_key_exists($key, $arr)) {
            $arr[$key]++;
        } else {
            $arr[$key] = 1;
        }
    }
}
