<?php

namespace Smac\TicketBundle\Controller;

use Smac\TicketBundle\Entity\TicketThread;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Smac\TicketBundle\Entity\Ticket;

class DefaultController extends Controller
{
    public function listAction()
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $session = $request->getSession();

        $proj = $session->get('smac_context');

        $tickets = $em->getRepository('SmacTicketBundle:Ticket')->findFromProject($proj, Ticket::TICKET_STATUS_OPENED);
        //@todo: join con ticket
        return $this->render(
            'SmacTicketBundle:Default:list.html.twig',
            array(
                'tickets' => $tickets
            )
        );
    }

    public function viewAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $session = $request->getSession();

        $ticket = $em->getRepository('SmacTicketBundle:Ticket')->findWithComments($id);

        if (!$ticket) {
            throw $this->createNotFoundException('Ticket no encontrado');
        }

        $message = $this->get('doctrine_mongodb')
            ->getRepository('SmacMessageBundle:Message')
            ->find($ticket->getMessageUuid());

        if (!$message) {
            throw $this->createNotFoundException('Mensaje no encontrado');
        }

        $users = $em->getRepository('SmacProjectBundle:Project')->findAttachedUsers($ticket->getProject());

        return $this->render(
            'SmacTicketBundle:Default:view.html.twig',
            array(
                'ticket' => $ticket,
                'message' => $message,
                'users' => $users
            )
        );
    }

    public function closeAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $session = $request->getSession();
        $user = $this->get('security.context')->getToken()->getUser();
        $ticket = $em->getRepository('SmacTicketBundle:Ticket')->find($id);

        if (!$ticket) {
            throw $this->createNotFoundException('Ticket no encontrado');
        }

        $ticket->setStatus(Ticket::TICKET_STATUS_CLOSED);
        $thread = new TicketThread();
        $thread->setUser($user);
        $thread->setDateReg(new \DateTime());
        $thread->setTicket($ticket);
        $thread->setType(TicketThread::TYPE_STATUS);
        $thread->setInfo(Ticket::TICKET_STATUS_CLOSED);

        $em->persist($thread);
        $em->persist($ticket);
        $em->flush();

        $this->get('session')->getFlashBag()->add(
            'success',
            'Ticket #'.$ticket->getId().' cerrado.'
        );

        return $this->redirect($this->generateUrl('smac_ticket_list'));
    }

    public function assignAction($id, $user)
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $session = $request->getSession();

        $ticket = $em->getRepository('SmacTicketBundle:Ticket')->find($id);

        if (!$ticket) {
            throw $this->createNotFoundException('Ticket no encontrado');
        }

        $user = $em->getRepository('SmacUserBundle:User')->find($user);

        if (!$user) {
            throw $this->createNotFoundException('Usuario no encontrado');
        }

        $ticket->setAssigned($user);
        $thread = new TicketThread();
        $thread->setUser($user);
        $thread->setDateReg(new \DateTime());
        $thread->setTicket($ticket);
        $thread->setType(TicketThread::TYPE_ASSIGN);
        $thread->setInfo($user->getId());

        $em->persist($thread);
        $em->persist($ticket);
        $em->flush();

        $this->get('session')->getFlashBag()->add(
            'success',
            'Usuario asignado correctamente'
        );

        return $this->redirect($this->generateUrl('smac_ticket_view', array('id'=>$id)));
    }

    /**
     * Comento un ticket y creao un Thread para guardar registro
     *
     * @param $id
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
     */
    public function commentAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $request = $this->getRequest();
        $form = $request->request;

        $ticket = $em->getRepository('SmacTicketBundle:Ticket')->find($id);
        $user = $this->get('security.context')->getToken()->getUser();

        if (!$ticket) {
            throw $this->createNotFoundException('Ticket no encontrado');
        }

        //creo la entidad Thread con toda la información
        $thread = new TicketThread();
        $thread->setDateReg(new \DateTime());
        $thread->setUser($user);
        $thread->setText($form->get('message'));
        $thread->setTicket($ticket);
        $thread->setType(TicketThread::TYPE_COMMENT);

        $em->persist($thread);
        $em->persist($ticket);
        $em->flush();

        $this->get('session')->getFlashBag()->add(
            'success',
            'Comentario registrado correctamente'
        );

        return $this->redirect($this->generateUrl('smac_ticket_view', array('id'=>$id)));
    }
}
