<?php

namespace Smac\TicketBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Ticket
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="Smac\TicketBundle\Entity\TicketRepository")
 */
class Ticket
{
    const TICKET_STATUS_OPENED = 1;
    const TICKET_STATUS_CLOSED = 2;

    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     */
    private $name;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\ProjectBundle\Entity\Project", inversedBy="tickets")
     * @ORM\JoinColumn(name="project_id", referencedColumnName="id")
     */
    private $project;

    /**
     * @var string
     *
     * @ORM\Column(name="messageUuid", type="string", length=255)
     */
    private $messageUuid;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_reg", type="datetime")
     */
    private $dateReg;

    /**
     * @ORM\OneToMany(targetEntity="Smac\TicketBundle\Entity\TicketThread", mappedBy="ticket")
     */
    private $threads;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\UserBundle\Entity\User", inversedBy="createdTickets")
     * @ORM\JoinColumn(name="user_id", referencedColumnName="id")
     */
    private $user;

    /**
     * @ORM\ManyToOne(targetEntity="Smac\UserBundle\Entity\User", inversedBy="assignedTickets")
     * @ORM\JoinColumn(name="assigned_id", referencedColumnName="id")
     */
    private $assigned;

    /**
     * @var integer
     *
     * @ORM\Column(name="status", type="integer")
     */
    private $status;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Ticket
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set messageUuid
     *
     * @param string $messageUuid
     * @return Ticket
     */
    public function setMessageUuid($messageUuid)
    {
        $this->messageUuid = $messageUuid;

        return $this;
    }

    /**
     * Get messageUuid
     *
     * @return string 
     */
    public function getMessageUuid()
    {
        return $this->messageUuid;
    }

    /**
     * Set dateReg
     *
     * @param \DateTime $dateReg
     * @return Ticket
     */
    public function setDateReg($dateReg)
    {
        $this->dateReg = $dateReg;

        return $this;
    }

    /**
     * Get dateReg
     *
     * @return \DateTime 
     */
    public function getDateReg()
    {
        return $this->dateReg;
    }

    /**
     * Set project
     *
     * @param \Smac\ProjectBundle\Entity\Project $project
     * @return Ticket
     */
    public function setProject(\Smac\ProjectBundle\Entity\Project $project = null)
    {
        $this->project = $project;

        return $this;
    }

    /**
     * Get project
     *
     * @return \Smac\ProjectBundle\Entity\Project 
     */
    public function getProject()
    {
        return $this->project;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->threads = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     * Add threads
     *
     * @param \Smac\TicketBundle\Entity\TicketThread $threads
     * @return Ticket
     */
    public function addThread(\Smac\TicketBundle\Entity\TicketThread $threads)
    {
        $this->threads[] = $threads;

        return $this;
    }

    /**
     * Remove threads
     *
     * @param \Smac\TicketBundle\Entity\TicketThread $threads
     */
    public function removeThread(\Smac\TicketBundle\Entity\TicketThread $threads)
    {
        $this->threads->removeElement($threads);
    }

    /**
     * Get threads
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getThreads()
    {
        return $this->threads;
    }

    /**
     * Set user
     *
     * @param \Smac\UserBundle\Entity\User $user
     * @return Ticket
     */
    public function setUser(\Smac\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;

        return $this;
    }

    /**
     * Get user
     *
     * @return \Smac\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * Set status
     *
     * @param integer $status
     * @return Ticket
     */
    public function setStatus($status)
    {
        $this->status = $status;

        return $this;
    }

    /**
     * Get status
     *
     * @return integer 
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * Set assigned
     *
     * @param \Smac\UserBundle\Entity\User $assigned
     * @return Ticket
     */
    public function setAssigned(\Smac\UserBundle\Entity\User $assigned = null)
    {
        $this->assigned = $assigned;

        return $this;
    }

    /**
     * Get assigned
     *
     * @return \Smac\UserBundle\Entity\User 
     */
    public function getAssigned()
    {
        return $this->assigned;
    }
}
