<?php

namespace Smac\UserBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Security\Core\SecurityContext;
use Smac\UserBundle\Entity\User;
use Smac\UserBundle\Form\UserType;

class DefaultController extends Controller
{
    public function indexAction()
    {
        $user = $this->get('security.context')->getToken()->getUser();
        $name = $user->getName();
        return $this->render('SmacUserBundle:Default:index.html.twig', array('name' => $name));
    }

    public function loginAction()
    {
        $request = $this->getRequest();
        $session = $request->getSession();

        $error = $request->attributes->get(
            SecurityContext::AUTHENTICATION_ERROR,
            $session->get(SecurityContext::AUTHENTICATION_ERROR)
        );

        return $this->render(
            'SmacUserBundle:Default:login.html.twig',
            array(
                'last_username' => $session->get(SecurityContext::LAST_USERNAME),
                 'error' => $error
            )
        );
    }

    /**
     * Registro un usuario en el sistema
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function registerAction()
    {
        $request = $this->getRequest();

        $user = new User();
        $form = $this->createForm(new UserType(), $user);

        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if ($form->isValid()) {
                $encoder = $this->get('security.encoder_factory')
                    ->getEncoder($user);
                $user->setSalt(md5(time()));
                $encodedPwd = $encoder->encodePassword(
                    $user->getPassword(),
                    $user->getSalt()
                );
                $user->setPassword($encodedPwd);
                $em = $this->getDoctrine()->getManager();
                $em->persist($user);
                $em->flush();

                return $this->redirect($this->generateUrl('smac_user_register_landing'));
            }
        }

        return $this->render(
            'SmacUserBundle:Default:register.html.twig',
            array(
                'form' => $form->createView()
            )
        );
    }

    public function registerLandingAction()
    {
        return $this->render('SmacUserBundle:Default:register_landing.html.twig');
    }
}
